#
# spec file for package owfs
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libversion 3_2-1
Name:           owfs
Version:        3.2p1
Release:        3.22
License:        GPL-2.0
Summary:        1-Wire Virtual File System
Summary:        Virtual filesystem on top of owfs-libs providing access to 1-Wire networks
Url:            http://sourceforge.net/projects/owfs
Group:          System/Libraries
Source:         %{name}-%{version}.tar.gz
Source1:        owfs.tmpfiles
# PATCH-FIX-UPSTREAM owfs-php7.patch bugs@vdm-design.de -- Adds compilation support for PHP7
Patch0:         owfs-php7.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  ed
BuildRequires:  fdupes
BuildRequires:  libavahi-devel
BuildRequires:  libftdi1-devel
BuildRequires:  libtool
BuildRequires:  libusb-compat-devel
BuildRequires:  perl
%if 0%{?suse_version} <= 1500
BuildRequires:  php5-devel
%else
BuildRequires:  php7-devel
%endif
BuildRequires:  pkgconfig
BuildRequires:  swig
BuildRequires:  systemd
BuildRequires:  pkgconfig(fuse) >= 1.0
BuildRequires:  pkgconfig(libusb-1.0) >= 1.0.16
BuildRequires:  pkgconfig(python) >= 2.0
BuildRequires:  pkgconfig(python-2.7) >= 2.0
BuildRequires:  pkgconfig(python2) >= 2.0
BuildRequires:  pkgconfig(tcl) >= 8.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
OWFS is a userspace virtual filesystem providing access to 1-Wire networks.

%package devel
Summary:        Devel files for owfs
Group:          Development/Libraries/Other
Requires:       libcapi-%{libversion} = %{version}
Requires:       libow-%{libversion} = %{version}
Requires:       libownet-%{libversion} = %{version}
Requires:       owfs-php

%description devel
Files needed to write your own programs using the owfs libraries.

%package -n libow-%{libversion}
Summary:        Core library providing base functions to other OWFS modules
Group:          System/Libraries

%description -n libow-%{libversion}
Core library providing base functions to other OWFS modules.

%package -n libowcapi-%{libversion}
Summary:        C-API to develop third-part applications which access 1-Wire networks
Group:          System/Libraries

%description -n libowcapi-%{libversion}
C-API library on top of libow providing an easy API to develop third-part applications
to access to 1-Wire networks.

%package -n libownet-%{libversion}
Summary:        C-API to develop third-part applications which access 1-Wire networks
Group:          System/Libraries

%description -n libownet-%{libversion}
Ownet library provids an easy API to develop third-part applications to access to 1-Wire networks.
It doesn't depend on owlib, and only supports remote-server connections.
This library doesn't include any 1-wire adapter support, except server connections.

%package fs
Summary:        Virtual filesystem on top of owfs-libs providing access to 1-Wire networks
Group:          System/Daemons

%description fs
Virtual filesystem on top of owfs-libs providing access to 1-Wire networks.

%package httpd
Summary:        HTTP daemon providing access to 1-Wire networks
Group:          System/Daemons

%description httpd
HTTP daemon on top of owfs providing access to 1-Wire networks.

%package ftpd
Summary:        FTP daemon providing access to 1-Wire networks
Group:          System/Daemons

%description ftpd
FTP daemon on top of owfs providing access to 1-Wire networks.

%package server
Summary:        Backend server (daemon) for 1-wire control
Group:          System/Daemons

%description server
The backend component of the OWFS 1-wire bus control system.
owserver arbitrates access to the bus from multiple client processes. The
physical bus is usually connected to a serial or USB port, and other processes
connect to owserver over network sockets (tcp port). Communication can be local
or over a network.

%package tap
Summary:        Packet sniffer for the owserver protocol
Group:          System/Daemons

%description tap
Packet sniffer for the owserver protocol

%package mon
Summary:        Statistics and settings monitor for owserver
Group:          System/Daemons

%description mon
Graphical monitor of owserver\'s status

%package -n perl-owfs
Summary:        Perl interface for the 1-wire filesystem
Group:          System/Libraries
Requires:       perl-base

%description -n perl-owfs
Perl interface for the 1-wire filesystem

%package -n python-owfs
Summary:        Python interface for the 1-wire filesystem
Group:          System/Libraries
Requires:       python-base

%description -n python-owfs
Python interface for the 1-wire filesystem

%package php
Summary:        Php interface for the 1-wire filesystem
Group:          System/Libraries

%description php
Php interface for the 1-wire filesystem

%if 0%{?suse_version} < 1500
%package tcl
Summary:        Tcl interface for the 1-wire filesystem
Group:          System/Libraries

%description tcl
Tcl interface for the 1-wire filesystem
%endif

%package shell
Summary:        Light weight shell access to owserver and the 1-wire filesystem
Group:          System/Console

%description shell
Small programs to easily access owserver (and thus the 1-wire system) from shell scripts.

%prep
%setup -q
%patch0 -p1

%build
export CFLAGS="%{optflags}"
./bootstrap

./configure \
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--disable-static \
	--enable-debian \
	--enable-usb \
	--enable-owfs \
	--enable-owhttpd \
	--enable-owcapi \
	--enable-ownetlib \
	--enable-owftpd \
	--enable-owserver \
	--enable-owtap \
	--enable-owmon \
	--enable-owperl \
	--enable-owpython \
	--enable-owphp \
%if 0%{?suse_version} < 1500
	--enable-owtcl \
%else
    --disable-owtcl \
%endif
	--enable-ftdi \
	--with-systemdsystemunitdir=%{_unitdir} \

make %{?_smp_mflags}

%install
%if 0%{?sles_version} <= 11
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%else
%make_install
%endif

install -d -m 0755 %{buildroot}%{_includedir}/owfs
mv -f %{buildroot}%{_includedir}/*.h %{buildroot}%{_includedir}/owfs

sed -i "s/User=ow/User=daemon/g" %{buildroot}%{_unitdir}/owhttpd.service
sed -i "s/Group=ow/Group=root/g" %{buildroot}%{_unitdir}/owhttpd.service
sed -i "s/User=ow/User=daemon/g" %{buildroot}%{_unitdir}/owftpd.service
sed -i "s/Group=ow/Group=root/g" %{buildroot}%{_unitdir}/owftpd.service
sed -i "s/User=ow/User=daemon/g" %{buildroot}%{_unitdir}/owserver.service
sed -i "s/Group=ow/Group=root/g" %{buildroot}%{_unitdir}/owserver.service

install -d -m 0755 %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf

%if 0%{?suse_version} < 1500
install -d -m 755 %{buildroot}%{_datadir}/tcl%{tcl_version}/owtcl-1.0
mv -f %{buildroot}%{_libdir}/owtcl-1.0/pkgIndex.tcl %{buildroot}%{_datadir}/tcl%{tcl_version}/owtcl-1.0
%else
rm -f %{buildroot}%{_mandir}/mann/owtcl.*
%endif

rm -f %{buildroot}%{_mandir}/man1/*.1so %{buildroot}%{_mandir}/man1/*.1so.gz
rm -f %{buildroot}%{_mandir}/man3/*.3so %{buildroot}%{_mandir}/man3/*.3so.gz
rm -f %{buildroot}%{_mandir}/man5/*.5so %{buildroot}%{_mandir}/man5/*.5so.gz
rm -f %{buildroot}%{_mandir}/mann/*.nso %{buildroot}%{_mandir}/mann/*.nso.gz
rm -f %{buildroot}%{perl_archlib}/perllocal.pod
rm -f %{buildroot}%{perl_vendorarch}/auto/OW/.packlist
rm -f %{buildroot}%{perl_vendorarch}/auto/OWNet/.packlist
rm -f %{buildroot}%{_libdir}/php5/extensions/libowphp.la %{buildroot}%{_libdir}/php5/extensions/libowphp.a
rm -f %{buildroot}%{_libdir}/owtcl-*/ow.la %{buildroot}%{_libdir}/owtcl-*/ow.a
find %{buildroot} -type f -name "*.la" -delete -print
rm -f %{buildroot}%{_libdir}/python*/site-packages/ownet/connection.pyc
rm -f %{buildroot}%{_libdir}/python*/site-packages/ow/__init__.pyc
rm -f %{buildroot}%{_libdir}/python*/site-packages/ownet/__init__.pyc

install -d -m 0755 %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcowfs
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcowftpd
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcowhttpd
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcowserver

%fdupes -s %{buildroot}/%{_mandir}

%post -n libow-%{libversion} -p /sbin/ldconfig

%postun -n libow-%{libversion} -p /sbin/ldconfig

%post -n libowcapi-%{libversion} -p /sbin/ldconfig

%postun -n libowcapi-%{libversion} -p /sbin/ldconfig

%post -n libownet-%{libversion} -p /sbin/ldconfig

%postun -n libownet-%{libversion} -p /sbin/ldconfig

%pre fs
%service_add_pre owfs.service

%post fs
%service_add_post owfs.service
systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf

%preun fs
%service_del_preun owfs.service

%postun fs
%service_del_postun owfs.service

%pre httpd
%service_add_pre owhttpd.service

%post httpd
%service_add_post owhttpd.service

%preun httpd
%service_del_preun owhttpd.service

%postun httpd
%service_del_postun owhttpd.service

%pre ftpd
%service_add_pre owftpd.service

%post ftpd
%service_add_post owftpd.service

%preun ftpd
%service_del_preun owftpd.service

%postun ftpd
%service_del_postun owftpd.service

%pre server
%service_add_pre owserver.service
%service_add_pre owserver.socket

%post server
%service_add_post owserver.service
%service_add_post owserver.socket

%preun server
%service_del_preun owserver.service
%service_del_preun owserver.socket

%postun server
%service_del_postun owserver.service
%service_del_postun owserver.socket


%files devel
%defattr(-,root,root)
%dir %{_includedir}/owfs
%{_includedir}/owfs/owfs_config.h
%{_includedir}/owfs/owcapi.h
%{_includedir}/owfs/ownetapi.h
%{_libdir}/libowcapi.so
%{_libdir}/libow.so
%{_libdir}/libownet.so
%if 0%{?suse_version} <= 1500
%{_libdir}/php5/extensions/libowphp.so
%else
%{_libdir}/php7/extensions/libowphp.so
%endif

%files -n libow-%{libversion}
%defattr(-,root,root)
%doc README NEWS ChangeLog AUTHORS COPYING
%{_libdir}/libow-*.so*
%{_mandir}/man3/DS1427.3.gz
%{_mandir}/man3/DS1821.3.gz
%{_mandir}/man3/DS1822.3.gz
%{_mandir}/man3/DS1825.3.gz
%{_mandir}/man3/DS18B20.3.gz
%{_mandir}/man3/DS18S20.3.gz
%{_mandir}/man3/DS1904.3.gz
%{_mandir}/man3/DS1920.3.gz
%{_mandir}/man3/DS1921.3.gz
%{_mandir}/man3/DS1963L.3.gz
%{_mandir}/man3/DS1963S.3.gz
%{_mandir}/man3/DS1971.3.gz
%{_mandir}/man3/DS1977.3.gz
%{_mandir}/man3/DS1982.3.gz
%{_mandir}/man3/DS1982U.3.gz
%{_mandir}/man3/DS1985.3.gz
%{_mandir}/man3/DS1985U.3.gz
%{_mandir}/man3/DS1986.3.gz
%{_mandir}/man3/DS1986U.3.gz
%{_mandir}/man3/DS1990A.3.gz
%{_mandir}/man3/DS1991.3.gz
%{_mandir}/man3/DS1992.3.gz
%{_mandir}/man3/DS1993.3.gz
%{_mandir}/man3/DS1994.3.gz
%{_mandir}/man3/DS1995.3.gz
%{_mandir}/man3/DS1996.3.gz
%{_mandir}/man3/DS2401.3.gz
%{_mandir}/man3/DS2404.3.gz
%{_mandir}/man3/DS2404S.3.gz
%{_mandir}/man3/DS2405.3.gz
%{_mandir}/man3/DS2406.3.gz
%{_mandir}/man3/DS2407.3.gz
%{_mandir}/man3/DS2408.3.gz
%{_mandir}/man3/DS2409.3.gz
%{_mandir}/man3/DS2411.3.gz
%{_mandir}/man3/DS2413.3.gz
%{_mandir}/man3/DS2415.3.gz
%{_mandir}/man3/DS2417.3.gz
%{_mandir}/man3/DS2423.3.gz
%{_mandir}/man3/DS2430A.3.gz
%{_mandir}/man3/DS2431.3.gz
%{_mandir}/man3/DS2433.3.gz
%{_mandir}/man3/DS2436.3.gz
%{_mandir}/man3/DS2437.3.gz
%{_mandir}/man3/DS2438.3.gz
%{_mandir}/man3/DS2450.3.gz
%{_mandir}/man3/DS2502-E48.3.gz
%{_mandir}/man3/DS2502-UNW.3.gz
%{_mandir}/man3/DS2502.3.gz
%{_mandir}/man3/DS2505-UNW.3.gz
%{_mandir}/man3/DS2505.3.gz
%{_mandir}/man3/DS2506-UNW.3.gz
%{_mandir}/man3/DS2506.3.gz
%{_mandir}/man3/DS2720.3.gz
%{_mandir}/man3/DS2740.3.gz
%{_mandir}/man3/DS2751.3.gz
%{_mandir}/man3/DS2755.3.gz
%{_mandir}/man3/DS2756.3.gz
%{_mandir}/man3/DS2760.3.gz
%{_mandir}/man3/DS2761.3.gz
%{_mandir}/man3/DS2762.3.gz
%{_mandir}/man3/DS2770.3.gz
%{_mandir}/man3/DS2780.3.gz
%{_mandir}/man3/DS2781.3.gz
%{_mandir}/man3/DS2788.3.gz
%{_mandir}/man3/DS2804.3.gz
%{_mandir}/man3/DS2890.3.gz
%{_mandir}/man3/DS28E04.3.gz
%{_mandir}/man3/DS28EA00.3.gz
%{_mandir}/man3/DS28EC20.3.gz
%{_mandir}/man3/EDS.3.gz
%{_mandir}/man3/EDS0064.3.gz
%{_mandir}/man3/EDS0065.3.gz
%{_mandir}/man3/EDS0066.3.gz
%{_mandir}/man3/EDS0067.3.gz
%{_mandir}/man3/EDS0068.3.gz
%{_mandir}/man3/EDS0071.3.gz
%{_mandir}/man3/EDS0072.3.gz
%{_mandir}/man3/EEEF.3.gz
%{_mandir}/man3/LCD.3.gz
%{_mandir}/man3/MAX31826.3.gz
%{_mandir}/man3/Thermachron.3.gz
%{_mandir}/man3/UVI.3.gz
%{_mandir}/man3/mAM001.3.gz
%{_mandir}/man3/mCM001.3.gz
%{_mandir}/man3/mRS001.3.gz
%{_mandir}/man3/mDI001.3.gz
%{_mandir}/man3/EDS0070.3.gz
%{_mandir}/man3/EDS0080.3.gz
%{_mandir}/man3/EDS0082.3.gz
%{_mandir}/man3/EDS0083.3.gz
%{_mandir}/man3/EDS0085.3.gz
%{_mandir}/man3/EDS0090.3.gz
%{_mandir}/man3/MAX31820.3.gz
%{_mandir}/man3/MAX31850.3.gz
%{_mandir}/man3/MAX31851.3.gz
%{_mandir}/man3/IBLSS.3.gz

%files -n libowcapi-%{libversion}
%defattr(-,root,root)
%{_libdir}/libowcapi-*.so*
%{_mandir}/man1/*owcapi.1.*

%files -n libownet-%{libversion}
%defattr(-,root,root)
%{_libdir}/libownet-*.so*
%{_mandir}/man1/*ownet*.1.*

%files fs
%defattr(-,root,root)
%{_unitdir}/owfs.service
%{_sbindir}/rcowfs
%{_tmpfilesdir}/%{name}.conf
%{_bindir}/owfs
%{_mandir}/man1/owfs.1.*
%{_mandir}/man5/owfs.5.*
%{_mandir}/man5/owfs.conf.5.*
%if 0%{?suse_version} > 1310
%ghost %{_rundir}/owfs
%else
%ghost /run/owfs
%endif

%files httpd
%defattr(-,root,root)
%{_unitdir}/owhttpd.service
%{_sbindir}/rcowhttpd
%{_bindir}/owhttpd
%{_mandir}/man1/owhttpd.1.*

%files shell
%defattr(-,root,root)
%{_bindir}/owdir
%{_bindir}/owread
%{_bindir}/owwrite
%{_bindir}/owget
%{_bindir}/owpresent
%{_bindir}/owexist
%{_bindir}/owexternal
%{_bindir}/owusbprobe
%{_mandir}/man1/owshell.1.*
%{_mandir}/man1/owdir.1.*
%{_mandir}/man1/owexist.1.*
%{_mandir}/man1/owread.1.*
%{_mandir}/man1/owget.1.*
%{_mandir}/man1/owpresent.1.*
%{_mandir}/man1/owwrite.1.*
%{_mandir}/mann/ow.n.*

%files ftpd
%defattr(-,root,root)
%{_unitdir}/owftpd.service
%{_sbindir}/rcowftpd
%{_bindir}/owftpd
%{_mandir}/man1/owftpd.1.*

%files server
%defattr(-,root,root)
%{_unitdir}/owserver.service
%{_sbindir}/rcowserver
%{_unitdir}/owserver.socket
%{_bindir}/owserver
%{_mandir}/man1/owserver.1.*

%files tap
%defattr(-,root,root)
%{_bindir}/owtap
%{_mandir}/man1/owtap.1.*

%files mon
%defattr(-,root,root)
%{_bindir}/owmon
%{_mandir}/man1/owmon.1.*

%files  -n perl-owfs
%defattr(-,root,root)
%dir %{perl_vendorarch}/auto
%dir %{perl_vendorarch}/auto/OW
%{perl_vendorarch}/auto/OW/OW.*
%{perl_vendorarch}/OW.pm
%{perl_vendorlib}/OWNet.pm
%{_mandir}/man3/OWNet.3*
%{_mandir}/man3/owperl.3.gz

%files -n python-owfs
%defattr(-,root,root)
%{_libdir}/python*/site-packages/ow-*.egg-info
%dir %{_libdir}/python*/site-packages/ow
%{_libdir}/python*/site-packages/ow/_OW.so
%{_libdir}/python*/site-packages/ow/__init__.py
%{_libdir}/python*/site-packages/ownet-*.egg-info
%dir %{_libdir}/python*/site-packages/ownet
%{_libdir}/python*/site-packages/ownet/__init__.py
%{_libdir}/python*/site-packages/ownet/connection.py

%files php
%defattr(-,root,root)
%if 0%{?suse_version} <= 1500
%dir %{_libdir}/php5/extensions
%{_libdir}/php5/extensions/libowphp.so.*
%else
%dir %{_libdir}/php7/extensions
%{_libdir}/php7/extensions/libowphp.so.*
%endif
%dir %{_datadir}/php
%dir %{_datadir}/php/OWNet
%{_datadir}/php/OWNet/ownet.php

%if 0%{?suse_version} < 1500
%files tcl
%defattr(-,root,root)
%dir %{_datadir}/tcl%{tcl_version}
%{_datadir}/tcl%{tcl_version}/owtcl-*/
%{_libdir}/owtcl-*/
%{_mandir}/mann/owtcl.n.*
%endif

%changelog
* Wed Mar  7 2018 bugs@vdm-design.de
- Add patch owfs-php7.patch to fix compilation against php7
- Disable owtcl for tumbleweed as it requires libieee which is gone
* Sun Jan  7 2018 bugs@vdm-design.de
- Tumbleweed dropped php5, disable owfs-php package
* Tue Jul 18 2017 bugs@vdm-design.de
- update to version 3.2p1
  * Support for the iButtonLink SmartSlave Wall-TH
  * DS2438: added humidity calculation for HIH5030/5031 based designs
  * added mechanism for secondary family codes; added A6 family code for DS2438
  * fixed buffer overflow in LINK host adapter version string parsing
  * EDS0065 humidity hi and low values are floats
* Mon Feb 13 2017 bugs@vdm-design.de
- clean up spec file
* Sat Feb 11 2017 bugs@vdm-design.de
- update to version 3.1p5
  * DS2409 fixes
  * DS2408 fixes
  * Add libftdi support
  * Add owusbprobe
  * Add tempres node to set power-on resolution on DS18B20, DS1822, DS1825, DS28EA00
  * fixed 85°C reading for latesttemp node on DS18B20 et al.
- remove libusb-include.patch, as it is included upstream
* Tue Jun  9 2015 bugs@vdm-design.de
- Fix compilation against libusb-1.0
  * Add patch libusb-include.patch which adds libusb-1.0 include
    path in several places.
* Sat Mar 28 2015 bugs@vdm-design.de
- update to version 3.1p0
  * Adds minor changes to the K1WM Bus Master from Martin Rapavy for the
    Kisler moification of the synthesized DS1WM Bus Master.
  * Major change in linkage. We leave behind the legacy version of
    libusb for the modern version. Libusb is used for the DS9490 Bus Master,
    and the older version is actually no longer supported, except as a legacy
    skin over the modern code.
* Sun Mar  1 2015 bugs@vdm-design.de
- update to version 3.0p1
    New Features.
    1. owhttpd supports "sparse arrays"
    A. Based on feedback by Eugenio Torrini
    B. Sparse arrays allow the file extension to have any value, e.g. a
    password in the case of the DS1991
    C. owhttpd now has an extension input field for sparse arrays
    D. web pages still don't require javascript or HTML5 features
    E. Fully backwards compatible
    2. Preliminary DS1WM support
    A. This is the freely available 1-wire bus master design from Maxim
    B. Can be implemented in FPGA
    C. Preliminary feedback and testing from Martin Rapavy
    D. Needs a hardware address for mapping device registers
    E. Maps system memory directly -- root only
    F. Competes with an in-kernel w1 module
    Fixes
    1. Fixed DS1991 support
    A. Based on observations and testing by Eugenio Torrini
    B. Uses a different directory structure
    a. subkey0, subkey1, subkey2
    C. Follows datasheet more closely
    D. NOT BACKWARDS COMPATIBLE
    But the old way didn't work so clearly wasn't being used.
- changes in version 3.0p0
    New Features.
    1. Monitor configuration file changes
    A. Use operating system to see if any othe configuration files have been changed
    B. Restart the program if changes (owserver, owfs, owhttpd, owftpd, owcapi)
    C. Let launchd and system restart for us -- just exit
    2. Launchd support.
    A. Launchd is sensed from the OS
    B. Avoids fork, daemon.
    C. Gets socket from plist
    Fixes
    1. OSX compiles cleanly
    2. Cygwin compiles cleanly
* Wed Jan  7 2015 bugs@vdm-design.de
- update to version 2.9p9
  Minor improvement -- basically fixes the owfs problem:
  "cat: temperature: Message too long"
* Sun Oct 19 2014 bugs@vdm-design.de
- update to version 2.9p8
  * New Features
    1. Filesystem fixed (owfs)
    Old double-free mutex bug fixed
    2. soelim utility now used for man file installation -- Stefano Miccoli
    3. systemd now manages mountpoints -- Tomasz Torcz
  * Fixes
    1. Numerous fixes from Coverity scan
    Null serial number in alias file
    Filelength calculation of directories
    Pointer errors in owftpd
    Fuse command line processing
    2. swig gave error even with good write -- fixed
    3. DS18S20 staircase bug fixed, again.
    Vincent Danjean
    Mario Gruenwald
    http://developer.mbed.org/users/snatch59/notebook/onewirecrc/
    4. OWFS (filesystem) wasn't honoring forground request
    5. Clean up some Makefile problems (lint files)
* Thu Oct  9 2014 bugs@vdm-design.de
- install upstream systemd files
  but change user/group from ow/ow to daemon/root
* Thu Oct  9 2014 bugs@vdm-design.de
- update to version 2.9p7
  * New Features
    1. HobbyBoards Masterhub
    A. New 4-port hub
    B. USB suport
    C. Ethernet not yet implemented
    D. Autodiscovery not yet implemented
    2. New HobbyBoards Sensors
    A. Updated Moisture Meter
    B. Humidity
    C. Barometer
    3. Improved systemd support -- Tomasz Torcz
  * Fixes
    1. Mutex errors and checking, including read-write lock error -- Christian Magnusson
    2. Longer timeput needed for FTDI serial adapters -- Johan Ström
    3. FreeBSD fixes -- Johan Ström
    4. mucl C library support -- der_tiger and Szabocls Nagy
    5. Numerous fixes found by Coverity analysis
    6. Configuration script fixes from Christian Magnusson and der_tiger
    7. owcapi bug in OW_present -- Valery Grusdev
    8. ownet payload size off by one -- Hans-Frieder Vogt
    9. OSX mutex error -- Stefano Miccoli
  10. Show HobbyBoard device version in decimal rather than hex
  11. MAX31850 Termocouple correction -- Paul Panish
  12. Endiaan fix for DS2408 -- Johan Ström
  13. DS18B20 resolution fix -- Johan Ström
  14. Python trouble with verion from CVS -- Johan Ström
* Mon Oct  6 2014 bugs@vdm-design.de
- Fix Bug #899880
  in the init script for the fs daemon the wrong variable for the binary was used
* Thu May  8 2014 bugs@vdm-design.de
- spec-cleaner run on owfs.spec
* Mon May  5 2014 bugs@vdm-design.de
- update to version 2.9p5
  * Fixes:
    1. Token creation problem from Stefano Miccoli
    2. Select when no DS2409 (Microlan hub) present Found by Johan Strom
- fixes from 2.9p4
  * New features
    1. Switch to git for source management
    Still hosted on sourceforge.net
    git clone git://git.code.sf.net/p/owfs/code owfs-code
    cvs history brought over.
    2. Clean and test DS2409 (Microlan) hubs
    Addressing problem found by Ors Tiszay
    Works well with passive devices
    Problems with powered slaves, but probably not a software issue.
    3. Improved and tested owserver protocol for server-to-server communication
    Use md5 hash for unique token
    Fixed byte counting issue in write messages
    Null-terminated string no longer required in path string
    (problem pointed out by Stefano Miccoli)
    4. Added /system/configuration/version
    Reports owserver version
    Request from Stefano Miccoli
  * Fixes
    1. Double initialization of mutex fixed
    Show stopper in FreeBSD
    Found by Johan Strom
* Mon Apr 14 2014 bugs@vdm-design.de
- update to version 2.9p3
  * New features
    1. Support for using other channels during temperature conversion Only selected bus masters, specifically not DS2484-800
    2. Add "Safe" owcapi init functions (for Sven Geggus) Allows multiple init calls without restarting library Only first call has device parameters analyzed. OW_init -> OW_safe_init OW_init_args -> OW_safe_init_args
    3. Add --trim option (for Michael Markstaller) Numeric values are trimmed of whitespace owget, owcapi, owfs, owftpd, owhttpd, owperl, OWNET.pm
    4. Support for Dirk Opfer's unannounced bus master
  * Fixes
    1. httpd json error reporting (bad url) fixed.
    2. httpd text error reporting fixed
    3. json formatting fixes
    4. json trailing comma in directory lists removed
    5. Endian errors in DS2413 etc fixed Thanks to Robin Gilks!
  Changes from 2.9p2:
  * New features
    1. Add support for the MAX31850 and MAX31851 thermocouple chips
    2. Add support for the EDS0090 Digital IO device
  * Fixes
    1. Change round for uClibc compatibility
    2. Fix owhttpd "Bad URL" page to actually work
    3. FreeBSD fixes from Johan Ström
    4. Update man pages for EDS devices and thermocouples
* Fri Jun 21 2013 bugs@vdm-design.de
- update to version 2.9p1
  * New features
  1. Add --detail to allow debugging for specific slave see http://owfs.org/index.php?page=debugging
  2. Json improvements -- Andrew Elwell
  3. CMCIEL's mDI001 digital monitor support
  * Fixes
  1. Clear mission for Thermochron -- Egger Clemmens
  2. Man page fixes -- Egger Clemmens
  3. Memory leak fix -- Marcel Krueger
  4. simultaneous directory cache problem -- Don Velno
  5. TAI8570 fix -- tj (Dave)
  6. ownet python patch -- Doug Werner
* Fri Apr 26 2013 bugs@vdm-design.de
- Update to version 2.9p0
* Thu Dec 20 2012 bugs@vdm-design.de
- initial release
